@@ -435,12 +435,12 @@ class Protocol(object):
                 if current_packet_size>self.max_packet_size:
                     #this packet is seemingly too big, but check again from the main UI thread
                     #this gives 'set_max_packet_size' a chance to run
-                    def check_packet_size(size_to_check):
-                        log("check_packet_size(%s) limit is %s", size_to_check, self.max_packet_size)
+                    def check_packet_size(size_to_check, packet_header):
+                        log("check_packet_size(%s, %s) limit is %s", size_to_check, packet_header, self.max_packet_size)
                         if size_to_check>self.max_packet_size:
-                            return self._call_connection_lost("invalid packet: size requested is %s (maximum allowed is %s), dropping this connection!" %
-                                                              (size_to_check, self.max_packet_size))
-                    gobject.idle_add(check_packet_size, current_packet_size)
+                            return self._call_connection_lost("invalid packet: size requested is %s (maximum allowed is %s - packet header: '%s'), dropping this connection!" %
+                                                              (size_to_check, self.max_packet_size, packet_header))
+                    gobject.timeout_add(1000, check_packet_size, current_packet_size, read_buffer[:32])
 
                 if current_packet_size>0 and bl<current_packet_size:
                     # incomplete packet, wait for the rest to arrive
